==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Dropdown/Dropdown.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.array.join.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import '../node_modules/core-js/modules/es.array.map.js';
import '../node_modules/core-js/modules/es.number.constructor.js';
import '../node_modules/core-js/modules/es.array.splice.js';
import { Icon } from '../Icon/index.js';
import { Callout } from '../Callout/Callout.js';
import '../Button/BaseButton.js';
import { ActionButton } from '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { Label } from '../Label/index.js';
import { Checkbox } from '../Checkbox/index.js';
import '../node_modules/core-js/modules/es.array.find-index.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var DropdownBase = function (_BaseComponent) {
  _inherits(DropdownBase, _BaseComponent);

  var _super = _createSuper(DropdownBase);

  function DropdownBase() {
    var _this;

    _classCallCheck(this, DropdownBase);

    _this = _super.apply(this, arguments);
    _this.isOpen = false;
    _this.calloutRenderEdge = null;
    return _this;
  }

  _createClass(DropdownBase, [{
    key: "created",
    value: function created() {
      var _this2 = this;

      this.options.forEach(function (option) {
        _this2.$set(option, 'isItemSelected', false);
      });
    }
  }, {
    key: "select",
    value: function select(option) {
      if (option.disabled) return;
      var index = this.selectedOptions.findIndex(function (o) {
        return o.key === option.key;
      });

      if (index > -1) {
        this.selectedOptions[index].isItemSelected = false;
        this.selectedOptions.splice(index, 1);
      } else {
        if (!this.multiSelect) {
          this.selectedOptions.splice(0, this.selectedOptions.length);
          this.isOpen = false;
        }

        option.isItemSelected = true;
        this.selectedOptions.push(option);
      }
    }
  }, {
    key: "onPositioned",
    value: function onPositioned(positions) {
      if (!this.calloutRenderEdge || this.calloutRenderEdge !== positions.targetEdge) {
        this.calloutRenderEdge = positions.targetEdge;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var h = arguments[0];
      var classNames = this.classNames,
          label = this.label,
          selectedOptions = this.selectedOptions,
          multiSelect = this.multiSelect,
          multiSelectDelimiter = this.multiSelectDelimiter,
          placeholder = this.placeholder,
          isOpen = this.isOpen,
          dropdownWidth = this.dropdownWidth,
          options = this.options,
          hasErrorMessage = this.hasErrorMessage,
          errorMessage = this.errorMessage,
          required = this.required,
          disabled = this.disabled;
      var OptionComponent = multiSelect ? Checkbox : ActionButton;
      return h("div", {
        "class": classNames.root
      }, [h(Label, {
        "class": classNames.label,
        "attrs": {
          "required": required,
          "disabled": disabled
        }
      }, [label]), h("div", {
        "ref": "dropdown",
        "class": classNames.dropdown,
        "on": {
          "click": function click() {
            return _this3.isOpen = true;
          }
        }
      }, [h("span", {
        "class": classNames.title
      }, [selectedOptions.length ? selectedOptions.map(function (i) {
        return i.text;
      }).join(multiSelectDelimiter) : placeholder]), h("span", {
        "class": classNames.caretDownWrapper
      }, [h(Icon, {
        "class": classNames.caretDown,
        "attrs": {
          "icon-name": "ChevronDown"
        }
      })])]), isOpen && h("div", [h(Callout, {
        "attrs": {
          "target": this.$refs.dropdown,
          "is-beak-visible": false,
          "callout-width": dropdownWidth || (this.$refs.dropdown ? this.$refs.dropdown.clientWidth : 0)
        },
        "on": {
          "dismiss": function dismiss() {
            return _this3.isOpen = false;
          },
          "positioned": this.onPositioned
        }
      }, [h("div", {
        "class": classNames.dropdownItemsWrapper,
        "attrs": {
          "tabindex": 0
        }
      }, [options.map(function (option, index) {
        return h(OptionComponent, {
          "key": index,
          "class": option.hidden ? classNames.dropdownItemHidden : option.isItemSelected && option.disabled === true ? classNames.dropdownItemSelectedAndDisabled : option.isItemSelected ? classNames.dropdownItemSelected : option.disabled === true ? classNames.dropdownItemDisabled : classNames.dropdownItem,
          "attrs": {
            "disabled": option.disabled,
            "title": option.text,
            "checked": option.isItemSelected,
            "styles": multiSelect ? _this3.multiSelectItemStyles : null,
            "role": option
          },
          "nativeOn": {
            "click": function click() {
              return !multiSelect && _this3.select(option);
            }
          },
          "on": {
            "input": function input() {
              return multiSelect && _this3.select(option);
            }
          }
        }, [option.text]);
      })])])]), hasErrorMessage && h("div", {
        "attrs": {
          "role": "alert"
        },
        "class": classNames.errorMessage
      }, [errorMessage])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          errorMessage = this.errorMessage,
          label = this.label,
          required = this.required,
          disabled = this.disabled,
          panelProps = this.panelProps,
          calloutProps = this.calloutProps;
      var isOpen = this.isOpen,
          calloutRenderEdge = this.calloutRenderEdge;
      var selectedOptions = this.selectedOptions;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        hasError: !!(errorMessage && errorMessage.length > 0),
        hasLabel: !!label,
        isOpen: isOpen,
        required: required,
        disabled: disabled,
        isRenderingPlaceholder: !selectedOptions.length,
        panelClassName: panelProps ? panelProps.className : undefined,
        calloutClassName: calloutProps ? calloutProps.className : undefined,
        calloutRenderEdge: calloutRenderEdge
      });
    }
  }, {
    key: "multiSelectItemStyles",
    get: function get() {
      return this.classNames.subComponentStyles ? this.classNames.subComponentStyles.multiSelectItem : undefined;
    }
  }, {
    key: "hasErrorMessage",
    get: function get() {
      return this.errorMessage && this.errorMessage.length > 0;
    }
  }]);

  return DropdownBase;
}(BaseComponent);

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DropdownBase.prototype, "options", void 0);

__decorate([Prop({
  type: Array,
  "default": function _default() {
    return [];
  }
}), __metadata("design:type", Array)], DropdownBase.prototype, "selectedOptions", void 0);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], DropdownBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], DropdownBase.prototype, "placeholder", void 0);

__decorate([Prop({
  type: String,
  "default": ''
}), __metadata("design:type", String)], DropdownBase.prototype, "errorMessage", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "required", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "multiSelect", void 0);

__decorate([Prop({
  type: String,
  "default": ', '
}), __metadata("design:type", String)], DropdownBase.prototype, "multiSelectDelimiter", void 0);

__decorate([Prop({
  type: Number,
  "default": 0
}), __metadata("design:type", Number)], DropdownBase.prototype, "dropdownWidth", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "panelProps", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "calloutProps", void 0);

DropdownBase = __decorate([Component({
  components: {
    Callout: Callout,
    ActionButton: ActionButton,
    Checkbox: Checkbox,
    Icon: Icon,
    Label: Label
  }
})], DropdownBase);

export { DropdownBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Dropdown/Dropdown.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent.js';
import 'core-js/modules/es.array.for-each';
import 'core-js/modules/es.array.join';
import 'core-js/modules/web.dom-collections.for-each';
import 'core-js/modules/es.array.map';
import 'core-js/modules/es.number.constructor';
import 'core-js/modules/es.array.splice';
import { Icon } from '../Icon/index.js';
import { Callout } from '../Callout/Callout.js';
import '../Button/BaseButton.js';
import { ActionButton } from '../Button/ActionButton/ActionButton.js';
import '../Button/DefaultButton/DefaultButton.js';
import '../Button/PrimaryButton/PrimaryButton.js';
import '../Button/CommandBarButton/CommandBarButton.js';
import '../Button/CompoundButton/CompoundButton.js';
import '../Button/IconButton/IconButton.js';
import '../Button/MessageBarButton/MessageBarButton.js';
import { Label } from '../Label/index.js';
import { Checkbox } from '../Checkbox/index.js';
import 'core-js/modules/es.array.find-index';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction();

var DropdownBase = function (_BaseComponent) {
  _inherits(DropdownBase, _BaseComponent);

  var _super = _createSuper(DropdownBase);

  function DropdownBase() {
    var _this;

    _classCallCheck(this, DropdownBase);

    _this = _super.apply(this, arguments);
    _this.isOpen = false;
    _this.calloutRenderEdge = null;
    return _this;
  }

  _createClass(DropdownBase, [{
    key: "created",
    value: function created() {
      var _this2 = this;

      this.options.forEach(function (option) {
        _this2.$set(option, 'isItemSelected', false);
      });
    }
  }, {
    key: "select",
    value: function select(option) {
      if (option.disabled) return;
      var index = this.selectedOptions.findIndex(function (o) {
        return o.key === option.key;
      });

      if (index > -1) {
        this.selectedOptions[index].isItemSelected = false;
        this.selectedOptions.splice(index, 1);
      } else {
        if (!this.multiSelect) {
          this.selectedOptions.splice(0, this.selectedOptions.length);
          this.isOpen = false;
        }

        option.isItemSelected = true;
        this.selectedOptions.push(option);
      }
    }
  }, {
    key: "onPositioned",
    value: function onPositioned(positions) {
      if (!this.calloutRenderEdge || this.calloutRenderEdge !== positions.targetEdge) {
        this.calloutRenderEdge = positions.targetEdge;
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var h = arguments[0];
      var classNames = this.classNames,
          label = this.label,
          selectedOptions = this.selectedOptions,
          multiSelect = this.multiSelect,
          multiSelectDelimiter = this.multiSelectDelimiter,
          placeholder = this.placeholder,
          isOpen = this.isOpen,
          dropdownWidth = this.dropdownWidth,
          options = this.options,
          hasErrorMessage = this.hasErrorMessage,
          errorMessage = this.errorMessage,
          required = this.required,
          disabled = this.disabled;
      var OptionComponent = multiSelect ? Checkbox : ActionButton;
      return h("div", {
        "class": classNames.root
      }, [h(Label, {
        "class": classNames.label,
        "attrs": {
          "required": required,
          "disabled": disabled
        }
      }, [label]), h("div", {
        "ref": "dropdown",
        "class": classNames.dropdown,
        "on": {
          "click": function click() {
            return _this3.isOpen = true;
          }
        }
      }, [h("span", {
        "class": classNames.title
      }, [selectedOptions.length ? selectedOptions.map(function (i) {
        return i.text;
      }).join(multiSelectDelimiter) : placeholder]), h("span", {
        "class": classNames.caretDownWrapper
      }, [h(Icon, {
        "class": classNames.caretDown,
        "attrs": {
          "icon-name": "ChevronDown"
        }
      })])]), isOpen && h("div", [h(Callout, {
        "attrs": {
          "target": this.$refs.dropdown,
          "is-beak-visible": false,
          "callout-width": dropdownWidth || (this.$refs.dropdown ? this.$refs.dropdown.clientWidth : 0)
        },
        "on": {
          "dismiss": function dismiss() {
            return _this3.isOpen = false;
          },
          "positioned": this.onPositioned
        }
      }, [h("div", {
        "class": classNames.dropdownItemsWrapper,
        "attrs": {
          "tabindex": 0
        }
      }, [options.map(function (option, index) {
        return h(OptionComponent, {
          "key": index,
          "class": option.hidden ? classNames.dropdownItemHidden : option.isItemSelected && option.disabled === true ? classNames.dropdownItemSelectedAndDisabled : option.isItemSelected ? classNames.dropdownItemSelected : option.disabled === true ? classNames.dropdownItemDisabled : classNames.dropdownItem,
          "attrs": {
            "disabled": option.disabled,
            "title": option.text,
            "checked": option.isItemSelected,
            "styles": multiSelect ? _this3.multiSelectItemStyles : null,
            "role": option
          },
          "nativeOn": {
            "click": function click() {
              return !multiSelect && _this3.select(option);
            }
          },
          "on": {
            "input": function input() {
              return multiSelect && _this3.select(option);
            }
          }
        }, [option.text]);
      })])])]), hasErrorMessage && h("div", {
        "attrs": {
          "role": "alert"
        },
        "class": classNames.errorMessage
      }, [errorMessage])]);
    }
  }, {
    key: "classNames",
    get: function get() {
      var theme = this.theme,
          className = this.className,
          errorMessage = this.errorMessage,
          label = this.label,
          required = this.required,
          disabled = this.disabled,
          panelProps = this.panelProps,
          calloutProps = this.calloutProps;
      var isOpen = this.isOpen,
          calloutRenderEdge = this.calloutRenderEdge;
      var selectedOptions = this.selectedOptions;
      return getClassNames(this.styles, {
        theme: theme,
        className: className,
        hasError: !!(errorMessage && errorMessage.length > 0),
        hasLabel: !!label,
        isOpen: isOpen,
        required: required,
        disabled: disabled,
        isRenderingPlaceholder: !selectedOptions.length,
        panelClassName: panelProps ? panelProps.className : undefined,
        calloutClassName: calloutProps ? calloutProps.className : undefined,
        calloutRenderEdge: calloutRenderEdge
      });
    }
  }, {
    key: "multiSelectItemStyles",
    get: function get() {
      return this.classNames.subComponentStyles ? this.classNames.subComponentStyles.multiSelectItem : undefined;
    }
  }, {
    key: "hasErrorMessage",
    get: function get() {
      return this.errorMessage && this.errorMessage.length > 0;
    }
  }]);

  return DropdownBase;
}(BaseComponent);

__decorate([Prop({
  type: Array,
  required: true
}), __metadata("design:type", Array)], DropdownBase.prototype, "options", void 0);

__decorate([Prop({
  type: Array,
  default: function _default() {
    return [];
  }
}), __metadata("design:type", Array)], DropdownBase.prototype, "selectedOptions", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "label", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "placeholder", void 0);

__decorate([Prop({
  type: String,
  default: ''
}), __metadata("design:type", String)], DropdownBase.prototype, "errorMessage", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "required", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DropdownBase.prototype, "multiSelect", void 0);

__decorate([Prop({
  type: String,
  default: ', '
}), __metadata("design:type", String)], DropdownBase.prototype, "multiSelectDelimiter", void 0);

__decorate([Prop({
  type: Number,
  default: 0
}), __metadata("design:type", Number)], DropdownBase.prototype, "dropdownWidth", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "panelProps", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {}
}), __metadata("design:type", Object)], DropdownBase.prototype, "calloutProps", void 0);

DropdownBase = __decorate([Component({
  components: {
    Callout: Callout,
    ActionButton: ActionButton,
    Checkbox: Checkbox,
    Icon: Icon,
    Label: Label
  }
})], DropdownBase);

export { DropdownBase };
